@@ -1,10 +1,7 @@
 import time
 from scrapeanything.scraper.scraper import Scraper
 from scrapeanything.utils.config import Config
-
-# import undetected_chromedriver.v2 as webdriver
 from selenium import webdriver
-
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.common.by import By
@@ -15,7 +12,7 @@ from selenium.common.exceptions import NoSuchElementException
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.remote.remote_connection import LOGGER
-import undetected_chromedriver.v2 as uc
+# import undetected_chromedriver.v2 as uc
 
 import logging
 import platform
@@ -29,13 +26,13 @@ class Selenium(Scraper):
 
         if user_dir is None or url is not None:
             options = webdriver.ChromeOptions()
-        else:
-            options = uc.ChromeOptions()
+        # else:
+        #     options = uc.ChromeOptions()
 
-            # another way to set profile is the below (which takes precedence if both variants are used
-            options.add_argument(f'--user-data-dir={user_dir}')
-            # just some options passing in to skip annoying popups
-            options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
+        #     # another way to set profile is the below (which takes precedence if both variants are used
+        #     options.add_argument(f'--user-data-dir={user_dir}')
+        #     # just some options passing in to skip annoying popups
+        #     options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
 
         #region options
         if fullscreen is True:
